==> dataqualitys-1.5.7-py3-none-any.whl: Utils/query_executor.py <==
# Placeholder for query_executor.py
from jinja2 import Environment, FileSystemLoader, PackageLoader, ChoiceLoader
import os
from typing import Dict, List
from .sql_helpers import quote_if_reserved

# class QueryExecutor:
#     def __init__(self, connector, db_type: str, config: Dict):
#         self.connector = connector
#         self.db_type = db_type
#         self.config = config
#
#         # Setup template environment with fallback
#         template_paths = [
#             os.path.join("templates", db_type),
#             os.path.join("templates", "common")
#         ]
#         self.env = Environment(
#             loader=FileSystemLoader(template_paths),
#             trim_blocks=True,
#             lstrip_blocks=True
#         )
class QueryExecutor:
    def __init__(self, connector, db_type: str, config: Dict):
        self.connector = connector
        self.db_type = db_type
        self.config = config

        # Local template paths for dev
        local_paths = [
            os.path.join(os.path.dirname(__file__), '..', 'templates', db_type),
            os.path.join(os.path.dirname(__file__), '..', 'templates', 'common')
        ]

        # Normalize paths
        local_paths = [os.path.abspath(path) for path in local_paths]

        # Use both FileSystemLoader (for dev) and PackageLoader (for installed)
        self.env = Environment(
            loader=ChoiceLoader([
                FileSystemLoader(local_paths),
                PackageLoader('dataqualitys', 'templates')
            ]),
            trim_blocks=True,
            lstrip_blocks=True
        )
    ''' def render_query(self, template_name: str, context: Dict) -> str:
        """  Process column names before rendering """
        if 'column_name' in context:
            context['column_name'] = quote_if_reserved(context['column_name'])
       
        """Render SQL template with context"""
        template = self.env.get_template(template_name)
        return template.render(context)
     '''
    def render_query(self, template_name: str, context: Dict) -> str:
        """Process column names before rendering"""
        if 'column_name' in context:
            context['column_name'] = quote_if_reserved(context['column_name'])
        
        # Add database name to context if available
        if 'database_name' not in context and 'database' in self.config:
            context['database_name'] = self.config['database']
        
        """Render SQL template with context"""
        template = self.env.get_template(template_name)
        return template.render(context)
    
    def execute(self, query: str) -> List[Dict]:
        """Execute query and return results"""
        return self.connector.run_query(query)

==> dataqualitys-1.8.7-py3-none-any.whl: Utils/query_executor.py <==
# Placeholder for query_executor.py
from jinja2 import Environment, FileSystemLoader, PackageLoader, ChoiceLoader
import os
from typing import Dict, List
from .sql_helpers import quote_if_reserved
class QueryExecutor:
    def __init__(self, connector, db_type: str, config: Dict):
        self.connector = connector
        self.db_type = db_type
        self.config = config

        # Setup template environment with fallback
        template_paths = [
            os.path.join("templates", db_type),
            os.path.join("templates", "common")
        ]
        self.env = Environment(
            loader=FileSystemLoader(template_paths),
            trim_blocks=True,
            lstrip_blocks=True
        )

    ''' def render_query(self, template_name: str, context: Dict) -> str:
        """  Process column names before rendering """
        if 'column_name' in context:
            context['column_name'] = quote_if_reserved(context['column_name'])

        """Render SQL template with context"""
        template = self.env.get_template(template_name)
        return template.render(context)
     '''

    def render_query(self, template_name: str, context: Dict) -> str:
        """Process column names before rendering"""
        if 'column_name' in context:
            context['column_name'] = quote_if_reserved(context['column_name'])

        # Add database name to context if available
        if 'database_name' not in context and 'database' in self.config:
            context['database_name'] = self.config['database']

        """Render SQL template with context"""
        template = self.env.get_template(template_name)
        return template.render(context)

    def execute(self, query: str) -> List[Dict]:
        """Execute query and return results"""
        return self.connector.run_query(query)
